Release History
===============

0.2.0 (2019-08-14)
~~~~~~~~~~~~~~~~~~

**Improvements**

- Added popup window for base and representative ``Molfile``s.
- Strip out html on paste event for editable table.
- Updated templates.
- Added error handling for "Base Identifier" column.
- Added CLI, GUI, API documentation.
- Added "isoenum_webgui" entry point.


0.1.0 (2019-07-30)
~~~~~~~~~~~~~~~~~~

- Initial public release.
